@@ -335,12 +335,6 @@ if (0 == $t_install_state) { ?>
 			echo '<option value="mysqli">MySqli</option>';
 		}
 		
-		if ($f_db_type == 'mssql') {
-			echo '<option value="mssql" selected="selected">Microsoft SQL Server (experimental)</option>';
-		} else {
-			echo '<option value="mssql">Microsoft SQL Server (experimental)</option>';
-		}
-		
 		if ($f_db_type == 'pgsql') {
 			echo '<option value="pgsql" selected="selected">PGSQL (experimental)</option>';
 		} else {
@@ -348,9 +342,9 @@ if (0 == $t_install_state) { ?>
 		}
 		
 		if ($f_db_type == 'oci8') {
-			echo '<option value="oci8" selected="selected">Oracle - oci8 (Experimental)</option>';
+			echo '<option value="oci8" selected="selected">Oracle - oci8 (experimental)</option>';
 		} else {
-			echo '<option value="oci8">Oracle - oci8 (Experimental)</option>';
+			echo '<option value="oci8">Oracle - oci8 (experimental)</option>';
 		}
 		
 		/************
@@ -399,7 +393,7 @@ if (0 == $t_install_state) { ?>
 </tr>
 
 <tr>
-	<td>Database name (for Database) <br />(For db2 set the value: dbname/schema )</td> <td><input name="database_name" value="<?php echo $f_database_name?>" type="textbox"></td>
+	<td>Database name (for Database)</td> <td><input name="database_name" value="<?php echo $f_database_name?>" type="textbox"></td>
 </tr>
 
 <tr>
